@@ -1,15 +1,10 @@
-# flake8: noqa: D101
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Literal
 
 if TYPE_CHECKING:
     import ast
-    from typing import Any, Generator, Tuple, TypedDict, Union
-
-    class ErrorDict(TypedDict):
-        error: str
-        node: ast.AST
+    from typing import Any, Generator, Optional, Protocol, Tuple, TypedDict, Union
 
     class FunctionRangesDict(TypedDict):
         start: int
@@ -20,3 +15,10 @@ if TYPE_CHECKING:
 
     Import = Union[ast.Import, ast.ImportFrom]
     Flake8Generator = Generator[Tuple[int, int, str, Any], None, None]
+
+    class Name(Protocol):
+        asname: Optional[str]
+        name: str
+
+
+ImportTypeValue = Literal['APPLICATION', 'THIRD_PARTY', 'BUILTIN', 'FUTURE']
